using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Telerik.WinControls.UI;

namespace GroupingSample
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            DataTable table = new DataTable("table");

            table.Columns.Add("ID", typeof(int));
            table.Columns.Add("Name", typeof(string));
            table.Columns.Add("City", typeof(string));
            table.Columns.Add("Experience", typeof(int));

            table.Rows.Add(1, "Nancy Davolio", "Seattle", 12);
            table.Rows.Add(2, "Andrew Fuller", "Tacoma", 4);
            table.Rows.Add(3, "Janet Leverling", "Kirkland", 6);
            table.Rows.Add(4, "Margaret Peacock", "Redmond", 8);
            table.Rows.Add(5, "Steven Buchanan", "London", 2);
            table.Rows.Add(6, "Michael Suyama", "London", 1);
            table.Rows.Add(7, "Robert King", "London", 1);
            table.Rows.Add(8, "Laura Callahan", "Seattle", 5);
            table.Rows.Add(9, "Anne Dodsworth", "London", 2);

            this.radGridView1.DataSource = table;
            this.radGridView1.Columns["City"].HeaderText = "Team Location";
            this.radGridView1.Columns["Experience"].HeaderText = "Work Experience (Years)";
            this.radGridView1.MasterGridViewTemplate.AutoExpandGroups = true;
            this.radGridView1.MasterGridViewTemplate.AllowAddNewRow = false;
            this.radGridView1.MasterGridViewTemplate.AutoSizeColumnsMode = GridViewAutoSizeColumnsMode.Fill;
            this.radGridView1.GroupSumaryEvaluate += new GroupSummaryEvaluateEventHandler(radGridView1_GroupSumaryEvaluate);
            this.radGridView1.ViewRowFormatting += new RowFormattingEventHandler(radGridView1_ViewRowFormatting);

            GridGroupByExpression expression = new GridGroupByExpression("City GroupBy City");
            this.radGridView1.MasterGridViewTemplate.GroupByExpressions.Add(expression);
            this.radGridView1.MasterGridViewTemplate.SummaryRowGroupHeaders[0].Add(new GridViewSummaryItem("Experience", "{0}", GridAggregateFunction.Sum));
        }

        void radGridView1_ViewRowFormatting(object sender, RowFormattingEventArgs e)
        {
            if (e.RowElement is GridGroupHeaderRowElement)
            {
                if (e.RowElement.IsCurrent)
                {
                    e.RowElement.GradientStyle = Telerik.WinControls.GradientStyles.Solid;
                    e.RowElement.BackColor = Color.FromArgb(255, 255, 198);
                    e.RowElement.DrawFill = true;
                }
                else
                {
                    e.RowElement.DrawFill = false;
                }
            }
        }

        //void radGridView1_GroupSumaryEvaluate(object sender, GroupSummaryEvaluationEventArgs e)
        //{
        //    e.FormatString = "" + e.Value + " has " + e.Group.RowCount + " row(s).";
        //}

        void radGridView1_GroupSumaryEvaluate(object sender, GroupSummaryEvaluationEventArgs e)
        {
            if (e.SummaryItem.FieldName == "Experience")
            {
                e.FormatString = " ";
            }
            else if (e.SummaryItem.FieldName == "City")
            {
                decimal sum = 0;
                foreach (Aggregate aggregate in e.Group.Aggregates)
                {
                    if (aggregate.AggregateFunction == GridAggregateFunction.Sum && aggregate.FieldName == "Experience")
                    {
                        sum = (decimal)aggregate.Value;
                    }
                }
                if (e.Group.RowCount == 1)
                {
                    e.FormatString = string.Format("{0} team has one member and his work experience is {1} year(s).", e.Value, sum);
                }
                else
                {
                    e.FormatString = string.Format("{0} team contains {1} members with summary work experience of {2} year(s).", e.Value, e.Group.RowCount, sum);
                }
            }
        }
    }
}